@@ -5,7 +5,8 @@ from .core import (
     gsheet_to_df,
     plotar_tabela_aggrid_colher_selecao,
     tratar_colunas_df_para_insercao_gsheet,
-    salvar_dados_bigquery
+    salvar_dados_bigquery,
+    carregar_dados_bigquery
 )
 
 __all__ = [
@@ -15,5 +16,6 @@ __all__ = [
     "gsheet_to_df",
     "plotar_tabela_aggrid_colher_selecao",
     "tratar_colunas_df_para_insercao_gsheet",
-    "salvar_dados_bigquery"
+    "salvar_dados_bigquery",
+    "carregar_dados_bigquery"
 ]
