@@ -1,14 +1,4 @@
-import pandas as pd
-import mysql.connector
-import decimal
-import gspread
-from google.oauth2 import service_account
 from typing import Optional
-from st_aggrid import AgGrid, GridOptionsBuilder
-from google.cloud import secretmanager, bigquery
-from pandas.api.types import is_period_dtype
-import re
-import json
 
 # Função para gerar DataFrame a partir de uma view do Phoenix
 
@@ -18,7 +8,11 @@ def gerar_df_phoenix(
         user_phoenix: str, # Nome de usuário do banco de dados
         password_phoenix: str, # Senha do banco de dados
         host_phoenix: str # Host do banco de dados
-    ) -> pd.DataFrame:
+    ) -> "pd.DataFrame":
+
+    import mysql.connector
+    import decimal
+    import pandas as pd
     
     config = {
         'user': user_phoenix, 
@@ -65,7 +59,10 @@ def gerar_df_phoenix(
 def abrir_planilha(
         id_gsheet: str, # ID da planilha do Google Sheets
         credenciais: dict # Credenciais do Google Sheets
-    ) -> gspread.Spreadsheet:
+    ) -> "gspread.Spreadsheet":
+
+    import gspread
+    from google.oauth2 import service_account
 
     credentials = service_account.Credentials.from_service_account_info(credenciais)
 
@@ -82,7 +79,7 @@ def abrir_planilha(
 # Função para tratar colunas de um DataFrame
 
 def tratar_colunas_df(
-        df: pd.DataFrame, # DataFrame a ser tratado
+        df: "pd.DataFrame", # DataFrame a ser tratado
         lista_colunas_numero: Optional[list] = None, # Lista de colunas numéricas
         nome_coluna_ref_ano_mes: Optional[str] = None, # Nome da coluna de referência para ano e mês
         lista_colunas_vazia_ou_none: Optional[list] = None, # Lista de colunas string p/ tratamento de ''
@@ -92,14 +89,16 @@ def tratar_colunas_df(
         formato_colunas_hora: Optional[str] = None, # Formato das colunas de hora
         lista_colunas_data_hora: Optional[list] = None, # Lista de colunas de data e hora
         formato_colunas_data_hora: Optional[str] = None # Formato das colunas de data e hora
-    ) -> pd.DataFrame:
+    ) -> "pd.DataFrame":
+
+    import pandas as pd
 
     # Função para adicionar colunas de ano, mês e mês/ano
 
     def adicionar_colunas_ano_mes(
-            df: pd.DataFrame, # DataFrame a ser tratado
+            df: "pd.DataFrame", # DataFrame a ser tratado
             coluna_data: Optional[str] = None # Nome da coluna de referência para ano e mês
-        ) -> pd.DataFrame:
+        ) -> "pd.DataFrame":
 
         if coluna_data is None:
 
@@ -188,7 +187,7 @@ def tratar_colunas_df(
 # Função para converter a aba do Google Sheets em um DataFrame
 
 def gsheet_to_df(
-        spread_sheet: gspread.Spreadsheet, # Planilha do Google
+        spread_sheet: "gspread.Spreadsheet", # Planilha do Google
         nome_aba: str, # Nome da aba a ser convertida
         lista_colunas_numero: Optional[list] = None, # Lista de colunas numéricas
         nome_coluna_ref_ano_mes: Optional[str] = None, # Nome da coluna de referência para ano e mês
@@ -199,7 +198,9 @@ def gsheet_to_df(
         formato_colunas_hora: Optional[str] = None, # Formato das colunas de hora
         lista_colunas_data_hora: Optional[list] = None, # Lista de colunas de data e hora
         formato_colunas_data_hora: Optional[str] = None # Formato das colunas de data e hora
-    ) -> pd.DataFrame:
+    ) -> "pd.DataFrame":
+
+    import pandas as pd
 
     sheet = spread_sheet.worksheet(nome_aba)
 
@@ -228,8 +229,8 @@ def gsheet_to_df(
 # Função para plotar tabela interativa e colher a seleção do usuário
 
 def plotar_tabela_aggrid_colher_selecao(
-        df: pd.DataFrame,
-        df_plotagem: pd.DataFrame,
+        df: "pd.DataFrame",
+        df_plotagem: "pd.DataFrame",
         config_selection: str,
         use_checkbox: bool,
         header_checkbox: bool,
@@ -238,7 +239,9 @@ def plotar_tabela_aggrid_colher_selecao(
         height: Optional[int] = None,
     ) -> list:
 
-    gb = GridOptionsBuilder.from_dataframe(df)
+    from st_aggrid import AgGrid, GridOptionsBuilder
+
+    gb = GridOptionsBuilder.from_dataframe(df_plotagem)
 
     gb.configure_selection(
         config_selection, 
@@ -259,7 +262,7 @@ def plotar_tabela_aggrid_colher_selecao(
     if autoHeight==False and height:
 
         grid_response = AgGrid(
-            df_plotagem, 
+            df, 
             gridOptions=gridOptions, 
             enable_enterprise_modules=False, 
             fit_columns_on_grid_load=True,
@@ -269,7 +272,7 @@ def plotar_tabela_aggrid_colher_selecao(
     else:
 
         grid_response = AgGrid(
-            df_plotagem, 
+            df, 
             gridOptions=gridOptions, 
             enable_enterprise_modules=False, 
             fit_columns_on_grid_load=True
@@ -283,14 +286,16 @@ def plotar_tabela_aggrid_colher_selecao(
 # podendo substituir os dados ou inserir na última linha
 
 def tratar_colunas_df_para_insercao_gsheet(
-        df_insercao: pd.DataFrame, # DataFrame a ser inserido
+        df_insercao: "pd.DataFrame", # DataFrame a ser inserido
         lista_colunas_data: Optional[list] = None, # Lista de colunas de data
         lista_colunas_data_hora: Optional[list] = None, # Lista de colunas de data e hora
         lista_colunas_hora: Optional[list] = None, # Lista de colunas de hora
         lista_colunas_str: Optional[list] = None, # Lista de colunas string
         lista_colunas_int: Optional[list] = None, # Lista de colunas inteiras
         lista_colunas_float: Optional[list] = None # Lista de colunas float
-    ) -> pd.DataFrame:
+    ) -> "pd.DataFrame":
+
+    import pandas as pd
 
     if lista_colunas_data:
 
@@ -356,11 +361,18 @@ def tratar_colunas_df_para_insercao_gsheet(
 # Função para inserir dataframe em um bigquery
 
 def salvar_dados_bigquery(
-        df_dados_atualizados: pd.DataFrame, 
+        df_dados_atualizados: "pd.DataFrame", 
         tabela_destino: str,
         project_id: str,
         secret_id: str
-    ) -> bigquery.LoadJob:
+    ) -> "bigquery.LoadJob":
+
+    from google.oauth2 import service_account
+    from google.cloud import secretmanager, bigquery
+    from pandas.api.types import is_period_dtype
+    import re
+    import json
+    import pandas as pd
 
     df_dados_atualizados.replace('', pd.NA, inplace=True)
 
@@ -373,7 +385,7 @@ def salvar_dados_bigquery(
     response = secret_client.access_secret_version(request={"name": secret_name})
 
     secret_payload = response.payload.data.decode("UTF-8")
-    
+
     credentials_info = json.loads(secret_payload)
 
     autenticar = service_account.Credentials.from_service_account_info(credentials_info)
@@ -407,4 +419,39 @@ def salvar_dados_bigquery(
 
     job.result()
 
-    return job
\ No newline at end of file
+    return "Dados enviados com sucesso!"
+
+# Função para carregar dados do BigQuery
+
+def carregar_dados_bigquery(
+        banco_dados: str, 
+        project_id: str, 
+        secret_id: str
+    ) -> "pd.DataFrame":
+
+    from google.oauth2 import service_account
+    from google.cloud import secretmanager, bigquery
+    import json
+
+    secret_client = secretmanager.SecretManagerServiceClient()
+
+    secret_name = f"projects/{project_id}/secrets/{secret_id}/versions/latest"
+
+    response = secret_client.access_secret_version(name=secret_name)
+
+    secret_data = response.payload.data.decode("UTF-8")
+
+    credentials_info = json.loads(secret_data)
+
+    autenticar = service_account.Credentials.from_service_account_info(credentials_info)
+
+    config_cliente = bigquery.Client(credentials=autenticar, project=autenticar.project_id)
+
+    consulta_geral = f"""
+    SELECT * 
+    FROM `{banco_dados}` 
+    """
+
+    df = config_cliente.query(consulta_geral).to_dataframe()
+
+    return df
\ No newline at end of file
